from setuptools import setup

long_desc = open('README.md').read()
print(long_desc)

setup(name='heleket',
      version='1.1',
      description='Python SDK for Heleket.com API',
      long_description_content_type='text/markdown',
      long_description=long_desc,
      packages=['heleket'],
      keywords=['Heleket', 'Heleket.com', 'API'],
      author='Daniil Gord',
      author_email='lexicon-nothing.0y@icloud.com',
      zip_safe=False,
      install_requires=['requests']
      )
